plaid_flutter library

Classes

LinkAccount
The account object
LinkAccountSubtype
The LinkAccountSubtype class defines the type and the subtype of an account.
LinkAccountSubtypeCredit
Credit subtypes
LinkAccountSubtypeDepository
Depository subtypes
LinkAccountSubtypeInvestment
Investment subtypes
LinkAccountSubtypeLoan
Loan subtypes
LinkError
The error object
LinkEvent
LinkEventMetadata
The metadata object for the onEvent callback
LinkExit
Exit event object
LinkExitMetadata
The metadata object for the onExit callback
LinkInstitution
The institution object
LinkOAuthConfiguration
The LinkOAuthConfiguration class defines the values used to configure the application for OAuth
LinkObject
Base for link events
LinkOnLoad
onLoad event object
LinkSuccess
Success event object
LinkSuccessMetadata
The metadata object for the onSuccess callback
LinkTokenConfiguration
PlaidEmbeddedView
Provides Plaid Link drop in functionality.
PlaidPlatformInterface
SubmissionData
Data to submit during a Link session.

Enums

LinkProduct
Options for specifying the Plaid products to use.